@@ -604,11 +604,11 @@ _bpm_propts = [
     [':ACQShots-SP', 1, 0.0],
     [':ACQTriggerRep-Sel', 0, 0.0],
     [':ACQBPMMode-Sel', 1, 0.0],
-    [':TbtTagEn-Sel', 1, 0.0],
-    [':TbtTagDly-SP', 0.0, 0.0],
-    [':TbtDataMaskEn-Sel', 1, 0.0],
-    [':TbtDataMaskSamplesBeg-SP', 0.0, 0.0],
-    [':TbtDataMaskSamplesEnd-SP', 0.0, 0.0],
+    [':TbTTagEn-Sel', 1, 0.0],
+    [':TbTTagDly-SP', 0.0, 0.0],
+    [':TbTDataMaskEn-Sel', 1, 0.0],
+    [':TbTDataMaskSamplesBeg-SP', 0.0, 0.0],
+    [':TbTDataMaskSamplesEnd-SP', 0.0, 0.0],
     [':RFFEAtt-SP', 31.5, 0.0],
     [':PosKsum-SP', 1, 0.0],
     [':PosXOffset-SP', 0, 0.0],
@@ -617,10 +617,10 @@ _bpm_propts = [
     [':ACQTriggerHwDly-SP', 0, 0.0],
     [':INFOClkFreq-SP', 220910069.0, 0.0],
     [':INFOHarmonicNumber-SP', 864, 0.0],
-    [':INFOTBTRate-SP', 382, 0.0],
+    [':INFOTbTRate-SP', 382, 0.0],
     [':INFOFOFBRate-SP', 8786, 0.0],
     [':INFOMONITRate-SP', 21929856, 0.0],
-    [':INFOMONIT1Rate-SP', 230346, 0.0],
+    [':INFOFAcqRate-SP', 230346, 0.0],
     [':PosKx-SP', 21389980, 0.0],
     [':PosKy-SP', 21389980, 0.0],
     [':PosKq-SP', 21389980, 0.0],
@@ -635,6 +635,14 @@ _bpm_propts = [
     [':SwTagEn-Sel', 0, 0.0],
     [':SwDataMaskEn-Sel', 0, 0.0],
     [':SwDataMaskSamples-SP', 1910, 0.0],
+    [':SwDirGainA-SP', 1.0, 0.0],
+    [':SwDirGainB-SP', 1.0, 0.0],
+    [':SwDirGainC-SP', 1.0, 0.0],
+    [':SwDirGainD-SP', 1.0, 0.0],
+    [':SwInvGainA-SP', 1.0, 0.0],
+    [':SwInvGainB-SP', 1.0, 0.0],
+    [':SwInvGainC-SP', 1.0, 0.0],
+    [':SwInvGainD-SP', 1.0, 0.0],
 ]
 _bpm_pvs = list()
 for dev in _bpms:
