@@ -13,6 +13,17 @@ from ..namesys import SiriusPVName as _PVName
 class BPM(_Device):
     """BPM Device."""
 
+    ACQSTATES_NOTOK = {
+            _csbpm.AcqStates.Error, _csbpm.AcqStates.No_Memory,
+            _csbpm.AcqStates.Too_Few_Samples,
+            _csbpm.AcqStates.Too_Many_Samples, _csbpm.AcqStates.Acq_Overflow}
+    ACQSTATES_STARTED = {
+        _csbpm.AcqStates.Waiting, _csbpm.AcqStates.External_Trig,
+        _csbpm.AcqStates.Data_Trig, _csbpm.AcqStates.Software_Trig,
+        _csbpm.AcqStates.Acquiring}
+    ACQSTATES_FINISHED = {_csbpm.AcqStates.Idle, _csbpm.AcqStates.Aborted}
+    ACQSTATES_FINISHED |= ACQSTATES_NOTOK
+
     _properties = (
         'asyn.ENBL', 'asyn.CNCT', 'SwMode-Sel', 'SwMode-Sts',
         'RFFEAtt-SP', 'RFFEAtt-RB',
@@ -26,8 +37,8 @@ class BPM(_Device):
         'SPAmplA-Mon', 'SPAmplB-Mon', 'SPAmplC-Mon', 'SPAmplD-Mon',
         'PosX-Mon', 'PosY-Mon', 'Sum-Mon', 'PosQ-Mon',
         'AmplA-Mon', 'AmplB-Mon', 'AmplC-Mon', 'AmplD-Mon',
-        'INFOClkFreq-RB', 'INFOHarmonicNumber-RB', 'INFOTBTRate-RB',
-        'INFOFOFBRate-RB', 'INFOMONITRate-RB', 'INFOMONIT1Rate-RB',
+        'INFOClkFreq-RB', 'INFOHarmonicNumber-RB', 'INFOTbTRate-RB',
+        'INFOFOFBRate-RB', 'INFOMONITRate-RB', 'INFOFAcqRate-RB',
         'GEN_PolyXArrayCoeff-SP', 'GEN_PolyXArrayCoeff-RB',
         'GEN_PolyYArrayCoeff-SP', 'GEN_PolyYArrayCoeff-RB',
         'GEN_PolySUMArrayCoeff-SP', 'GEN_PolySUMArrayCoeff-RB',
@@ -47,7 +58,7 @@ class BPM(_Device):
         'ACQSamplesPre-SP', 'ACQSamplesPre-RB',
         'ACQSamplesPost-SP', 'ACQSamplesPost-RB',
         'ACQTriggerEvent-Sel', 'ACQTriggerEvent-Sts',
-        'ACQStatus-Sts',
+        'ACQStatus-Sts', 'ACQCount-Mon',
         'ACQTrigger-Sel', 'ACQTrigger-Sts',
         'ACQTriggerRep-Sel', 'ACQTriggerRep-Sts',
         'ACQDataTrigChan-Sel', 'ACQDataTrigChan-Sts',
@@ -55,13 +66,13 @@ class BPM(_Device):
         'ACQTriggerDataThres-SP', 'ACQTriggerDataThres-RB',
         'ACQTriggerDataPol-Sel', 'ACQTriggerDataPol-Sts',
         'ACQTriggerDataHyst-SP', 'ACQTriggerDataHyst-RB',
-        'SwTagEn-Sel', 'SwTagEn-Sts',
-        'TbtTagEn-Sel', 'TbtTagEn-Sts',
-        'Monit1TagEn-Sel', 'Monit1TagEn-Sts',
+        'SwTagEn-Sel', 'SwTagEn-Sts', 'SwDivClk-RB',
+        'TbTTagEn-Sel', 'TbTTagEn-Sts',
+        'FAcqTagEn-Sel', 'FAcqTagEn-Sts',
         'MonitTagEn-Sel', 'MonitTagEn-Sts',
-        'TbtDataMaskEn-Sel', 'TbtDataMaskEn-Sts',
-        'TbtDataMaskSamplesBeg-SP', 'TbtDataMaskSamplesBeg-RB',
-        'TbtDataMaskSamplesEnd-SP', 'TbtDataMaskSamplesEnd-RB',
+        'TbTDataMaskEn-Sel', 'TbTDataMaskEn-Sts',
+        'TbTDataMaskSamplesBeg-SP', 'TbTDataMaskSamplesBeg-RB',
+        'TbTDataMaskSamplesEnd-SP', 'TbTDataMaskSamplesEnd-RB',
         'XYPosCal-Sel', 'XYPosCal-Sts',
         'SUMPosCal-Sel', 'SUMPosCal-Sts',
         'QPosCal-Sel', 'QPosCal-Sts',
@@ -69,13 +80,15 @@ class BPM(_Device):
 
     CONV_NM2UM = 1e-3  # [nm] --> [um]
 
-    def __init__(self, devname, auto_mon=True):
+    def __init__(self, devname, auto_mon=True, ispost_mortem=False):
         """."""
         # call base class constructor
         if not _BPMSearch.is_valid_devname(devname):
             raise ValueError(devname + ' is not a valid BPM or PBPM name.')
 
-        properties = set(BPM._properties)
+        self._ispost_mortem = ispost_mortem
+        properties = {self.get_propname(p) for p in BPM._properties}
+
         if _BPMSearch.is_photon_bpm(devname):
             properties -= {'RFFEAtt-SP', 'RFFEAtt-RB'}
         properties = list(properties)
@@ -117,10 +130,7 @@ class BPM(_Device):
     @property
     def is_ok(self):
         """."""
-        stts = _csbpm.AcqStates
-        okay = self.acq_status not in {
-            stts.Error, stts.No_Memory, stts.Too_Few_Samples,
-            stts.Too_Many_Samples, stts.Acq_Overflow}
+        okay = self.acq_status not in self.ACQSTATES_NOTOK
         okay &= self.asyn_connected == _csbpm.ConnTyp.Connected
         okay &= self.asyn_state == _csbpm.EnblTyp.Enable
         return okay
@@ -164,6 +174,32 @@ class BPM(_Device):
         """."""
         self['SwMode-Sel'] = val
 
+    @property
+    def switching_mode_str(self):
+        """."""
+        return _csbpm.SwModes._fields[self.switching_mode]
+
+    @property
+    def switching_rate(self):
+        """Switching rate manifested at BPM readings.
+
+        NOTE: Actually this property maps the rate of the effect of
+        switching on the orbit, which is twice the switching rate,
+        because the switching has two states.
+
+        """
+        return self['SwDivClk-RB'] * 2
+
+    @property
+    def switching_period(self):
+        """Switching period manifested at BPM readings."""
+        return self.switching_rate / self.adcfreq
+
+    @property
+    def harmonic_number(self):
+        """."""
+        return self['INFOHarmonicNumber-RB']
+
     @property
     def adcfreq(self):
         """."""
@@ -171,8 +207,8 @@ class BPM(_Device):
 
     @property
     def tbt_rate(self):
-        """."""
-        return self['INFOTBTRate-RB']
+        """Divisor or TbT in relation to ADC."""
+        return self['INFOTbTRate-RB']
 
     @property
     def tbt_period(self):
@@ -182,42 +218,42 @@ class BPM(_Device):
     @property
     def tbt_sync_enbl(self):
         """."""
-        return self['TbtTagEn-Sts']
+        return self['TbTTagEn-Sts']
 
     @tbt_sync_enbl.setter
     def tbt_sync_enbl(self, val):
         """."""
-        self['TbtTagEn-Sel'] = val
+        self['TbTTagEn-Sel'] = val
 
     @property
     def tbt_mask_enbl(self):
         """."""
-        return self['TbtDataMaskEn-Sts']
+        return self['TbTDataMaskEn-Sts']
 
     @tbt_mask_enbl.setter
     def tbt_mask_enbl(self, val):
         """."""
-        self['TbtDataMaskEn-Sel'] = val
+        self['TbTDataMaskEn-Sel'] = val
 
     @property
     def tbt_mask_beg(self):
         """."""
-        return self['TbtDataMaskSamplesBeg-RB']
+        return self['TbTDataMaskSamplesBeg-RB']
 
     @tbt_mask_beg.setter
     def tbt_mask_beg(self, val):
         """."""
-        self['TbtDataMaskSamplesBeg-SP'] = val
+        self['TbTDataMaskSamplesBeg-SP'] = val
 
     @property
     def tbt_mask_end(self):
         """."""
-        return self['TbtDataMaskSamplesEnd-RB']
+        return self['TbTDataMaskSamplesEnd-RB']
 
     @tbt_mask_end.setter
     def tbt_mask_end(self, val):
         """."""
-        self['TbtDataMaskSamplesEnd-SP'] = val
+        self['TbTDataMaskSamplesEnd-SP'] = val
 
     @property
     def fofb_sync_enbl(self):
@@ -231,7 +267,7 @@ class BPM(_Device):
 
     @property
     def fofb_rate(self):
-        """."""
+        """Divisor or FOFB in relation to ADC."""
         return self['INFOFOFBRate-RB']
 
     @property
@@ -240,28 +276,28 @@ class BPM(_Device):
         return self.fofb_rate / self.adcfreq
 
     @property
-    def monit1_rate(self):
-        """."""
-        return self['INFOMONIT1Rate-RB']
+    def facq_rate(self):
+        """Divisor or FAcq in relation to ADC."""
+        return self['INFOFAcqRate-RB']
 
     @property
-    def monit1_period(self):
+    def facq_period(self):
         """."""
-        return self.monit1_rate / self.adcfreq
+        return self.facq_rate / self.adcfreq
 
     @property
-    def monit1_sync_enbl(self):
+    def facq_sync_enbl(self):
         """."""
-        return self['Monit1TagEn']
+        return self['FAcqTagEn']
 
-    @monit1_sync_enbl.setter
-    def monit1_sync_enbl(self, val):
+    @facq_sync_enbl.setter
+    def facq_sync_enbl(self, val):
         """."""
-        self['Monit1TagEn-Sel'] = val
+        self['FAcqTagEn-Sel'] = val
 
     @property
     def monit_rate(self):
-        """."""
+        """Divisor or Monit in relation to ADC."""
         return self['INFOMONITRate-RB']
 
     @property
@@ -394,82 +430,82 @@ class BPM(_Device):
     @property
     def mt_posx(self):
         """."""
-        return self['GEN_XArrayData'] * self.CONV_NM2UM
+        return self[self.get_propname('GEN_XArrayData')] * self.CONV_NM2UM
 
     @property
     def mt_posy(self):
         """."""
-        return self['GEN_YArrayData'] * self.CONV_NM2UM
+        return self[self.get_propname('GEN_YArrayData')] * self.CONV_NM2UM
 
     @property
     def mt_possum(self):
         """."""
-        return self['GEN_SUMArrayData']
+        return self[self.get_propname('GEN_SUMArrayData')]
 
     @property
     def mt_posq(self):
         """."""
-        return self['GEN_QArrayData']
+        return self[self.get_propname('GEN_QArrayData')]
 
     @property
     def mt_ampla(self):
         """."""
-        return self['GEN_AArrayData']
+        return self[self.get_propname('GEN_AArrayData')]
 
     @property
     def mt_amplb(self):
         """."""
-        return self['GEN_BArrayData']
+        return self[self.get_propname('GEN_BArrayData')]
 
     @property
     def mt_amplc(self):
         """."""
-        return self['GEN_CArrayData']
+        return self[self.get_propname('GEN_CArrayData')]
 
     @property
     def mt_ampld(self):
         """."""
-        return self['GEN_DArrayData']
+        return self[self.get_propname('GEN_DArrayData')]
 
     @property
     def mt_polyx(self):
         """."""
-        return self['GEN_PolyXArrayCoeff-RB']
+        return self[self.get_propname('GEN_PolyXArrayCoeff-RB')]
 
     @mt_polyx.setter
     def mt_polyx(self, value):
         """."""
-        self['GEN_PolyXArrayCoeff-SP'] = _np.array(value)
+        self[self.get_propname('GEN_PolyXArrayCoeff-SP')] = _np.array(value)
 
     @property
     def mt_polyy(self):
         """."""
-        return self['GEN_PolyYArrayCoeff-RB']
+        return self[self.get_propname('GEN_PolyYArrayCoeff-RB')]
 
     @mt_polyy.setter
     def mt_polyy(self, value):
         """."""
-        self['GEN_PolyYArrayCoeff-SP'] = _np.array(value)
+        self[self.get_propname('GEN_PolyYArrayCoeff-SP')] = _np.array(value)
 
     @property
     def mt_polysum(self):
         """."""
-        return self['GEN_PolySUMArrayCoeff-RB']
+        return self[self.get_propname('GEN_PolySUMArrayCoeff-RB')]
 
     @mt_polysum.setter
     def mt_polysum(self, value):
         """."""
-        self['GEN_PolySUMArrayCoeff-SP'] = _np.array(value)
+        self[self.get_propname('GEN_PolySUMArrayCoeff-SP')] = _np.array(value)
 
     @property
     def mt_polyq(self):
         """."""
-        return self['GEN_PolyQArrayCoeff-RB']
+        return self[self.get_propname('GEN_PolyQArrayCoeff-RB')]
 
     @mt_polyq.setter
     def mt_polyq(self, value):
         """."""
-        self['GEN_PolyQArrayCoeff-SP'] = _np.array(value)
+        self[self.get_propname('GEN_PolyQArrayCoeff-SP')] = _np.array(value)
 
     @property
     def mt_polyxy_enbl(self):
@@ -504,22 +540,22 @@ class BPM(_Device):
     @property
     def mtraw_posx(self):
         """Multi turn raw X array data."""
-        return self['GEN_RawXArrayData']
+        return self[self.get_propname('GEN_RawXArrayData')] * self.CONV_NM2UM
 
     @property
     def mtraw_posy(self):
         """Multi turn raw Y array data."""
-        return self['GEN_RawYArrayData']
+        return self[self.get_propname('GEN_RawYArrayData')] * self.CONV_NM2UM
 
     @property
     def mtraw_possum(self):
         """Multi turn raw sum array data."""
-        return self['GEN_RawSUMArrayData']
+        return self[self.get_propname('GEN_RawSUMArrayData')]
 
     @property
     def mtraw_posq(self):
         """Multi turn raw Q array data."""
-        return self['GEN_RawQArrayData']
+        return self[self.get_propname('GEN_RawQArrayData')]
 
     @property
     def sp_posx(self):
@@ -584,181 +620,187 @@ class BPM(_Device):
     @property
     def acq_mode(self):
         """."""
-        return self['ACQBPMMode-Sts']
+        return self[self.get_propname('ACQBPMMode-Sts')]
 
     @acq_mode.setter
     def acq_mode(self, mode):
         """."""
-        self['ACQBPMMode-Sel'] = mode
+        self[self.get_propname('ACQBPMMode-Sel')] = mode
 
     @property
     def acq_ctrl(self):
         """."""
-        return self['ACQTriggerEvent-Sts']
+        return self[self.get_propname('ACQTriggerEvent-Sts')]
 
     @acq_ctrl.setter
     def acq_ctrl(self, val):
         """."""
-        self['ACQTriggerEvent-Sel'] = val
+        self[self.get_propname('ACQTriggerEvent-Sel')] = val
 
     @property
     def acq_status(self):
         """."""
-        return self['ACQStatus-Sts']
+        return self[self.get_propname('ACQStatus-Sts')]
+
+    @property
+    def acq_count(self):
+        """Counter of number of acquisitions so far."""
+        return self[self.get_propname('ACQCount-Mon')]
 
     @property
     def acq_channel(self):
         """."""
-        return self['ACQChannel-Sts']
+        return self[self.get_propname('ACQChannel-Sts')]
 
     @acq_channel.setter
     def acq_channel(self, val):
         """."""
-        self['ACQChannel-Sel'] = val
+        self[self.get_propname('ACQChannel-Sel')] = val
+
+    @property
+    def acq_channel_str(self):
+        """."""
+        return _csbpm.AcqChan._fields[self.acq_channel]
 
     @property
     def acq_trigger(self):
         """."""
-        return self['ACQTrigger-Sts']
+        return self[self.get_propname('ACQTrigger-Sts')]
 
     @acq_trigger.setter
     def acq_trigger(self, val):
         """."""
-        self['ACQTrigger-Sel'] = val
+        self[self.get_propname('ACQTrigger-Sel')] = val
 
     @property
     def acq_repeat(self):
         """."""
-        return self['ACQTriggerRep-Sts']
+        return self[self.get_propname('ACQTriggerRep-Sts')]
 
     @acq_repeat.setter
     def acq_repeat(self, val):
         """."""
-        self['ACQTriggerRep-Sel'] = val
+        self[self.get_propname('ACQTriggerRep-Sel')] = val
 
     @property
     def acq_update_time(self):
         """."""
-        return self['ACQUpdateTime-RB'] / 1e3
+        return self[self.get_propname('ACQUpdateTime-RB')]  / 1e3
 
     @acq_update_time.setter
     def acq_update_time(self, val):
         """."""
-        self['ACQUpdateTime-SP'] = val * 1e3
+        self[self.get_propname('ACQUpdateTime-SP')] = val * 1e3
 
     @property
     def acq_trig_datachan(self):
         """."""
-        return self['ACQDataTrigChan-Sts']
+        return self[self.get_propname('ACQDataTrigChan-Sts')]
 
     @acq_trig_datachan.setter
     def acq_trig_datachan(self, val):
         """."""
-        self['ACQDataTrigChan-Sel'] = val
+        self[self.get_propname('ACQDataTrigChan-Sel')] = val
 
     @property
     def acq_trig_datasel(self):
         """."""
-        return self['ACQTriggerDataSel-RB']
+        return self[self.get_propname('ACQTriggerDataSel-RB')]
 
     @acq_trig_datasel.setter
     def acq_trig_datasel(self, val):
         """."""
-        self['ACQTriggerDataSel-SP'] = val
+        self[self.get_propname('ACQTriggerDataSel-SP')] = val
 
     @property
     def acq_trig_datathres(self):
         """."""
-        return self['ACQTriggerDataThres-RB']
+        return self[self.get_propname('ACQTriggerDataThres-RB')]
 
     @acq_trig_datathres.setter
     def acq_trig_datathres(self, val):
         """."""
-        self['ACQTriggerDataThres-SP'] = val
+        self[self.get_propname('ACQTriggerDataThres-SP')] = val
 
     @property
     def acq_trig_datahyst(self):
         """."""
-        return self['ACQTriggerDataHyst-RB']
+        return self[self.get_propname('ACQTriggerDataHyst-RB')]
 
     @acq_trig_datahyst.setter
     def acq_trig_datahyst(self, val):
         """."""
-        self['ACQTriggerDataHyst-SP'] = val
+        self[self.get_propname('ACQTriggerDataHyst-SP')] = val
 
     @property
     def acq_trig_datapol(self):
         """."""
-        return self['ACQTriggerDataPol-RB']
+        return self[self.get_propname('ACQTriggerDataPol-RB')]
 
     @acq_trig_datapol.setter
     def acq_trig_datapol(self, val):
         """."""
-        self['ACQTriggerDataPol-SP'] = val
+        self[self.get_propname('ACQTriggerDataPol-SP')] = val
 
     @property
     def acq_nrsamples_post(self):
         """."""
-        return self['ACQSamplesPost-RB']
+        return self[self.get_propname('ACQSamplesPost-RB')]
 
     @acq_nrsamples_post.setter
     def acq_nrsamples_post(self, val):
         """."""
-        self['ACQSamplesPost-SP'] = val
+        self[self.get_propname('ACQSamplesPost-SP')] = val
 
     @property
     def acq_nrsamples_pre(self):
         """."""
-        return self['ACQSamplesPre-RB']
+        return self[self.get_propname('ACQSamplesPre-RB')]
 
     @acq_nrsamples_pre.setter
     def acq_nrsamples_pre(self, val):
         """."""
-        self['ACQSamplesPre-SP'] = val
+        self[self.get_propname('ACQSamplesPre-SP')] = val
 
     @property
     def acq_nrshots(self):
         """."""
-        return self['ACQShots-RB']
+        return self[self.get_propname('ACQShots-RB')]
 
     @acq_nrshots.setter
     def acq_nrshots(self, val):
         """."""
-        self['ACQShots-SP'] = val
+        self[self.get_propname('ACQShots-SP')] = val
 
     def wait_acq_finish(self, timeout=10):
         """Wait Acquisition to finish."""
-        vals = {
-            _csbpm.AcqStates.Idle, _csbpm.AcqStates.Error,
-            _csbpm.AcqStates.Aborted, _csbpm.AcqStates.Too_Many_Samples,
-            _csbpm.AcqStates.Too_Few_Samples, _csbpm.AcqStates.No_Memory,
-            _csbpm.AcqStates.Acq_Overflow}
         return self._wait(
-            'ACQStatus-Sts', vals, timeout=timeout, comp=lambda x, y: x in y)
+            self.get_propname('ACQStatus-Sts'), self.ACQSTATES_FINISHED,
+            timeout=timeout, comp=lambda x, y: x in y)
 
     def wait_acq_start(self, timeout=10):
         """Wait Acquisition to start."""
-        vals = {
-            _csbpm.AcqStates.Waiting, _csbpm.AcqStates.External_Trig,
-            _csbpm.AcqStates.Data_Trig, _csbpm.AcqStates.Software_Trig,
-            _csbpm.AcqStates.Acquiring}
         return self._wait(
-            'ACQStatus-Sts', vals, timeout=timeout, comp=lambda x, y: x in y)
+            self.get_propname('ACQStatus-Sts'), self.ACQSTATES_STARTED,
+            timeout=timeout, comp=lambda x, y: x in y)
 
     def cmd_acq_start(self):
         """Command Start Acquisition."""
         self.acq_ctrl = _csbpm.AcqEvents.Start
-        return self._wait('ACQTriggerEvent-Sts', _csbpm.AcqEvents.Start)
+        return self._wait(
+            self.get_propname('ACQTriggerEvent-Sts'), _csbpm.AcqEvents.Start)
 
     def cmd_acq_stop(self):
         """Command Stop Acquisition."""
         self.acq_ctrl = _csbpm.AcqEvents.Stop
-        return self._wait('ACQTriggerEvent-Sts', _csbpm.AcqEvents.Stop)
+        return self._wait(
+            self.get_propname('ACQTriggerEvent-Sts'), _csbpm.AcqEvents.Stop)
 
     def cmd_acq_abort(self):
         """Command Abort Acquisition."""
         self.acq_ctrl = _csbpm.AcqEvents.Abort
-        return self._wait('ACQTriggerEvent-Sts', _csbpm.AcqEvents.Abort)
+        return self._wait(
+            self.get_propname('ACQTriggerEvent-Sts'), _csbpm.AcqEvents.Abort)
 
     def cmd_turn_on_switching(self):
         """Command Turn on Switching."""
@@ -775,7 +817,7 @@ class BPM(_Device):
         self.tbt_sync_enbl = 1
         _time.sleep(0.1)
         self.tbt_sync_enbl = 0
-        return self._wait('TbtTagEn-Sts', 0)
+        return self._wait('TbTTagEn-Sts', 0)
 
     def cmd_sync_fofb(self):
         """Synchronize FOFB acquisitions with Timing System."""
@@ -784,19 +826,64 @@ class BPM(_Device):
         self.fofb_sync_enbl = 0
         return self._wait('SwTagEn-Sts', 0)
 
-    def cmd_sync_monit1(self):
-        """Synchronize Monit1 acquisitions with Timing System."""
-        self.monit1_sync_enbl = 1
+    def cmd_sync_facq(self):
+        """Synchronize FAcq acquisitions with Timing System."""
+        self.facq_sync_enbl = 1
         _time.sleep(0.1)
-        self.monit1_sync_enbl = 0
-        return self._wait('Monit1TagEn-Sts', 0)
+        self.facq_sync_enbl = 0
+        return self._wait('FAcqTagEn-Sts', 0)
 
     def cmd_sync_monit(self):
         """Synchronize Monit acquisitions with Timing System."""
         self.monit_sync_enbl = 1
         _time.sleep(0.1)
         self.monit_sync_enbl = 0
-        return self._wait('Monit1TagEn-Sts', 0)
+        return self._wait('FAcqTagEn-Sts', 0)
+
+    def get_sampling_frequency(
+            self, rf_freq: float, acq_rate='') -> float:
+        """Return the sampling frequency of the acquisition.
+
+        Args:
+            rf_freq (float): RF frequency.
+            acq_rate (str, optional): acquisition rate. Defaults to ''.
+            If empty string, it gets the configured acq. rate on BPMs
+
+        Returns:
+            float: acquisition frequency.
+
+        """
+        acq_rate = self.acq_channel_str if not acq_rate else acq_rate
+        fadc = rf_freq / self.harmonic_number * self.tbt_rate
+        if acq_rate.lower().startswith('tbt'):
+            return fadc / self.tbt_rate
+        elif acq_rate.lower().startswith('fofb'):
+            return fadc / self.fofb_rate
+        elif acq_rate.lower().startswith('facq'):
+            return fadc / self.facq_rate
+        return fadc / self.monit_rate
+
+    def get_switching_frequency(self, rf_freq: float) -> float:
+        """Return the switching frequency.
+
+        Args:
+            rf_freq (float): RF frequency.
+
+        Returns:
+            float: switching frequency.
+
+        """
+        fadc = rf_freq / self.harmonic_number * self.tbt_rate
+        return fadc / self.switching_rate
+
+    def get_propname(self, prop):
+        if not self._ispost_mortem:
+            return prop
+        if prop.startswith('GEN'):
+            return prop.replace('GEN', 'PM')
+        elif prop.startswith('ACQ'):
+            return prop.replace('ACQ', 'ACQ_PM')
+        return prop
 
 
 class FamBPMs(_Devices):
@@ -807,11 +894,12 @@ class FamBPMs(_Devices):
 
     class DEVICES:
         """."""
+
         SI = 'SI-Fam:DI-BPM'
         BO = 'BO-Fam:DI-BPM'
         ALL = (BO, SI)
 
-    def __init__(self, devname=None):
+    def __init__(self, devname=None, ispost_mortem=False):
         """."""
         if devname is None:
             devname = self.DEVICES.SI
@@ -821,20 +909,21 @@ class FamBPMs(_Devices):
         devname = _PVName(devname)
         bpm_names = _BPMSearch.get_names(
             filters={'sec': devname.sec, 'dev': devname.dev})
-        devs = [BPM(dev, auto_mon=False) for dev in bpm_names]
+        self._ispost_mortem = ispost_mortem
+        devs = [
+            BPM(dev, auto_mon=False, ispost_mortem=ispost_mortem)
+            for dev in bpm_names]
 
         super().__init__(devname, devs)
         self._bpm_names = bpm_names
         self._csbpm = devs[0].csdata
-        propties_to_keep = ['GEN_XArrayData', 'GEN_YArrayData']
 
         self._mturn_flags = dict()
         for bpm in devs:
-            for propty in propties_to_keep:
-                bpm.set_auto_monitor(propty, True)
-                pvo = bpm.pv_object(propty)
-                self._mturn_flags[pvo.pvname] = _Flag()
-                pvo.add_callback(self._mturn_set_flag)
+            pvo = bpm.pv_object(bpm.get_propname('ACQCount-Mon'))
+            pvo.auto_monitor = True
+            self._mturn_flags[pvo.pvname] = _Flag()
+            pvo.add_callback(self._mturn_set_flag)
 
     @property
     def bpm_names(self):
@@ -927,30 +1016,48 @@ class FamBPMs(_Devices):
             return orbx, orby
         return orbx, orby, _np.array(possum).T
 
-    @staticmethod
-    def get_sampling_frequency(rf_freq: float, acq_rate='Monit1'):
+    def get_sampling_frequency(self, rf_freq: float, acq_rate='') -> float:
         """Return the sampling frequency of the acquisition.
 
         Args:
             rf_freq (float): RF frequency.
-            acq_rate (str, optional): acquisition rate. Defaults to 'Monit1'.
+            acq_rate (str, optional): acquisition rate. Defaults to ''.
+            If empty string, it gets the configured acq. rate on BPMs
 
         Returns:
             float: acquisition frequency.
 
         """
-        fsamp = rf_freq / 864
-        if acq_rate.lower().startswith('tbt'):
-            return fsamp
-        fsamp /= 23
-        if acq_rate.lower().startswith('fofb'):
-            return fsamp
-        fsamp /= 25
-        return fsamp
+        fs_bpms = {
+            dev.get_sampling_frequency(rf_freq, acq_rate)
+            for dev in self.devices}
+        if len(fs_bpms) == 1:
+            return fs_bpms.pop()
+        else:
+            print('BPMs are not configured with the same ACQChannel.')
+            return None
+
+    def get_switching_frequency(self, rf_freq: float) -> float:
+        """Return the switching frequency.
+
+        Args:
+            rf_freq (float): RF frequency.
+
+        Returns:
+            float: switching frequency.
+
+        """
+        fsw_bpms = {
+            dev.get_switching_frequency(rf_freq) for dev in self.devices}
+        if len(fsw_bpms) == 1:
+            return fsw_bpms.pop()
+        else:
+            print('BPMs are not configured with the same SwMode.')
+            return None
 
     def mturn_config_acquisition(
             self, nr_points_after: int, nr_points_before=0,
-            acq_rate='Monit1', repeat=True, external=True):
+            acq_rate='FAcq', repeat=True, external=True) -> int:
         """Configure acquisition for BPMs.
 
         Args:
@@ -958,15 +1065,21 @@ class FamBPMs(_Devices):
             nr_points_before (int): number of points after trigger.
                 Defaults to 0.
             acq_rate (str, optional): Acquisition rate ('TbT', 'FOFB',
-                'Monit1'). Defaults to 'Monit1'.
+                'FAcq'). Defaults to 'FAcq'.
             repeat (bool, optional): Whether or not acquisition should be
                 repetitive. Defaults to True.
             external (bool, optional): Whether or not external trigger should
                 be used. Defaults to True.
 
+        Returns:
+            int: code describing what happened:
+                =0: BPMs are ready.
+                <0: Index of the first BPM which did not stop last acq. plus 1.
+                >0: Index of the first BPM which is not ready for acq. plus 1.
+
         """
-        if acq_rate.lower().startswith('monit1'):
-            acq_rate = self._csbpm.AcqChan.Monit1
+        if acq_rate.lower().startswith('facq'):
+            acq_rate = self._csbpm.AcqChan.FAcq
         elif acq_rate.lower().startswith('fofb'):
             acq_rate = self._csbpm.AcqChan.FOFB
         elif acq_rate.lower().startswith('tbt'):
@@ -984,7 +1097,9 @@ class FamBPMs(_Devices):
         else:
             trig = self._csbpm.AcqTrigTyp.Now
 
-        self.cmd_mturn_acq_abort()
+        ret = self.cmd_mturn_acq_abort()
+        if ret > 0:
+            return -ret
 
         for bpm in self._devices:
             bpm.acq_repeat = repeat
@@ -993,39 +1108,86 @@ class FamBPMs(_Devices):
             bpm.acq_nrsamples_pre = nr_points_before
             bpm.acq_nrsamples_post = nr_points_after
 
-        self.cmd_mturn_acq_start()
+        return self.cmd_mturn_acq_start()
 
-    def cmd_mturn_acq_abort(self) -> bool:
+    def cmd_mturn_acq_abort(self, wait=True, timeout=10) -> int:
         """Abort BPMs acquistion.
 
+        Args:
+            wait (bool, optional): whether or not to wait BPMs get ready.
+                Defaults to True.
+            timeout (int, optional): Time to wait. Defaults to 10.
+
         Returns:
-            bool: Whether or not abort was successful.
+            int: code describing what happened:
+                =0: BPMs are ready.
+                >0: Index of the first BPM which did not update plus 1.
 
         """
         for bpm in self._devices:
             bpm.acq_ctrl = self._csbpm.AcqEvents.Abort
 
-        for bpm in self._devices:
-            boo = bpm.wait_acq_finish()
-            if not boo:
-                return False
-        return True
+        if wait:
+            return self.wait_acquisition_finish(timeout=timeout)
+        return 0
 
-    def cmd_mturn_acq_start(self) -> bool:
-        """Start BPMs acquisition.
+    def wait_acquisition_finish(self, timeout=10) -> int:
+        """Wait for all BPMs to be ready for acquisition.
+
+        Args:
+            timeout (int, optional): Time to wait. Defaults to 10.
 
         Returns:
-            bool: Whether or not start was successful.
+            int: code describing what happened:
+                =0: BPMs are ready.
+                >0: Index of the first BPM which did not update plus 1.
+
+        """
+        for i, bpm in enumerate(self._devices):
+            t0_ = _time.time()
+            if not bpm.wait_acq_finish(timeout):
+                return i + 1
+            timeout -= _time.time() - t0_
+        return 0
+
+    def cmd_mturn_acq_start(self, wait=True, timeout=10) -> int:
+        """Start BPMs acquisition.
+
+        Args:
+            wait (bool, optional): whether or not to wait BPMs get ready.
+                Defaults to True.
+            timeout (int, optional): Time to wait. Defaults to 10.
+
+        Returns:
+            int: code describing what happened:
+                =0: BPMs are ready.
+                >0: Index of the first BPM which did not update plus 1.
 
         """
         for bpm in self._devices:
             bpm.acq_ctrl = self._csbpm.AcqEvents.Start
+        if wait:
+            return self.wait_acquisition_start(timeout=timeout)
+        return 0
 
-        for bpm in self._devices:
-            boo = bpm.wait_acq_start()
-            if not boo:
-                return False
-        return True
+    def wait_acquisition_start(self, timeout=10) -> bool:
+        """Wait for all BPMs to be ready for acquisition.
+
+        Args:
+            timeout (int, optional): Time to wait. Defaults to 10.
+
+        Returns:
+            int: code describing what happened:
+                =0: BPMs are ready.
+                >0: Index of the first BPM which did not update plus 1.
+
+        """
+        for i, bpm in enumerate(self._devices):
+            t0_ = _time.time()
+            if not bpm.wait_acq_start(timeout):
+                return i + 1
+            timeout -= _time.time() - t0_
+        return 0
 
     def set_switching_mode(self, mode='direct'):
         """Set switching mode of BPMS.
@@ -1044,48 +1206,79 @@ class FamBPMs(_Devices):
         for bpm in self._devices:
             bpm.switching_mode = mode
 
+    def mturn_update_initial_orbit(self, consider_sum=False):
+        """Call this method before acquisition to get orbit for comparison."""
+        self._initial_orbs = self.get_mturn_orbit(return_sum=consider_sum)
+
     def mturn_reset_flags(self):
         """Reset Multiturn flags to wait for a new orbit update."""
         for flag in self._mturn_flags.values():
             flag.clear()
 
-    def mturn_wait_update_flags(self, timeout=10) -> int:
-        """Wait Multiturn orbit update.
+    def mturn_reset_flags_and_update_initial_orbit(self, consider_sum=False):
+        """Set initial state to wait for orbit acquisition to start."""
+        self.mturn_reset_flags()
+        self.mturn_update_initial_orbit(consider_sum)
+
+    def mturn_wait_update_flags(self, timeout=10):
+        """Wait for all acquisition flags to be updated.
 
         Args:
-            timeout (int, optional): Waiting timeout. Defaults to 10.
+            timeout (int, optional): Time to wait. Defaults to 10.
 
         Returns:
             int: code describing what happened:
-                -2: TypeError ocurred
-                -1: Size of X orbit is different than Y orbit.
-                0: Orbit updated.
-                >0: Index of the first BPM which did not updated plus 1.
+                =0: BPMs are ready.
+                >0: Index of the first BPM which did not update plus 1.
 
         """
-        orbx0, orby0 = self.get_mturn_orbit()
         for i, flag in enumerate(self._mturn_flags.values()):
             t00 = _time.time()
             if not flag.wait(timeout=timeout):
-                return (i // 2) + 1
+                return i + 1
             timeout -= _time.time() - t00
             timeout = max(timeout, 0)
+        return 0
 
+    def mturn_wait_update_orbit(self, timeout=10, consider_sum=False) -> int:
+        """Call this method after acquisition to check if orbit was updated.
+
+        For this method to work it is necessary to call
+            mturn_update_initial_orbit
+        before the acquisition starts, so that a reference for comparison is
+        created.
+
+        Args:
+            timeout (int, optional): Waiting timeout. Defaults to 10.
+            consider_sum (bool, optional): Whether to also wait for sum signal
+                to be updated. Defaults to False.
+
+        Returns:
+            int: code describing what happened:
+                -4: unknown error;
+                -3: initial orbit was not acquired before acquisition;
+                -2: TypeError ocurred (maybe because some of them are None);
+                -1: Orbits have different sizes;
+                =0: Orbit updated.
+                >0: Index of the first BPM which did not update plus 1.
+
+        """
+        orbs0, self._initial_orbs = self._initial_orbs, None
+        if orbs0 is None:
+            return -3
         while timeout > 0:
             t00 = _time.time()
-            orbx, orby = self.get_mturn_orbit()
+            orbs = self.get_mturn_orbit(return_sum=consider_sum)
             typ = False
             try:
-                sizx = min(orbx.shape[0], orbx0.shape[0])
-                sizy = min(orby.shape[0], orby0.shape[0])
-                continue_ = sizx != sizy
-                errx = _np.all(
-                    _np.isclose(orbx0[:sizx], orbx[:sizx]), axis=0)
-                erry = _np.all(
-                    _np.isclose(orby0[:sizy], orby[:sizy]), axis=0)
-                continue_ |= _np.any(errx) | _np.any(erry)
+                sizes = [
+                    min(o.shape[0], o0.shape[0]) for o, o0 in zip(orbs, orbs0)]
+                continue_ = max(sizes) != min(sizes)
+                errs = _np.any([
+                    _np.all(_np.isclose(o[:s], o0[:s]), axis=0)
+                    for o, o0, s in zip(orbs, orbs0, sizes)], axis=0)
+                continue_ |= _np.any(errs)
             except TypeError:
-                print('TypeError')
                 typ = True
                 continue_ = True
             if not continue_:
@@ -1095,13 +1288,37 @@ class FamBPMs(_Devices):
 
         if typ:
             return -1
-        elif sizx != sizy:
+        elif max(sizes) != min(sizes):
             return -2
-        elif _np.any(errx):
-            return int(errx.nonzero()[0][0])+1
-        elif _np.any(erry):
-            return int(erry.nonzero()[0][0])+1
-        return False
+        elif _np.any(errs):
+            return int(errs.nonzero()[0][0])+1
+        return -4
+
+    def mturn_wait_update(self, timeout=10, consider_sum=False) -> int:
+        """Combine mturn_wait_update_flags and mturn_wait_update_orbit.
+
+        Args:
+            timeout (int, optional): Waiting timeout. Defaults to 10.
+            consider_sum (bool, optional): Whether to also wait for sum signal
+                to be updated. Defaults to False.
+
+        Returns:
+            int: code describing what happened:
+                -4: unknown error;
+                -3: initial orbit was not acquired before acquisition;
+                -2: TypeError ocurred (maybe because some of them are None);
+                -1: Orbits have different sizes;
+                =0: Orbit updated.
+                >0: Index of the first BPM which did not update plus 1.
+
+        """
+        t00 = _time.time()
+        ret = self.mturn_wait_update_flags(timeout)
+        if ret > 0:
+            return ret
+        timeout -= _time.time() - t00
+
+        return self.mturn_wait_update_orbit(timeout, consider_sum=consider_sum)
 
     def _mturn_set_flag(self, pvname, **kwargs):
         _ = kwargs
