@@ -42,7 +42,7 @@ class EVG(_Device):
     @nrpulses.setter
     def nrpulses(self, value):
         """Set number of pulses to repeat Bucket List."""
-        self['RepeatBucketList-SP'] = bool(value)
+        self['RepeatBucketList-SP'] = value
 
     @property
     def bucketlist_len(self):
@@ -370,6 +370,15 @@ class Trigger(_Device):
     def duration(self, value):
         self['Duration-SP'] = value
 
+    @property
+    def width_raw(self):
+        """Width of one pulse in hardware units."""
+        return self['WidthRaw-RB']
+
+    @width_raw.setter
+    def width_raw(self, value):
+        self['WidthRaw-SP'] = value
+
     @property
     def polarity(self):
         """Polarity."""
