@@ -15,19 +15,25 @@ class NormalizerFactory:
     """Factory class for normalizer objects."""
 
     @staticmethod
-    def create(maname):
+    def create(maname, **kwargs):
         """Return appropriate normalizer."""
         psname = _MASearch.conv_maname_2_psnames(maname)[0]
         magfunc = _PSSearch.conv_psname_2_magfunc(psname)
         ma_class = _mutil.magnet_class(maname)
         if ma_class == 'dipole':
-            return _norm.DipoleNormalizer(maname, magnet_conv_sign=-1.0)
+            kwargs['magnet_conv_sign'] = -1.0
+            return _norm.DipoleNormalizer(maname, **kwargs)
         if ma_class == 'trim':
-            return _norm.TrimNormalizer(maname, magnet_conv_sign=-1.0)
+            kwargs['magnet_conv_sign'] = -1.0
+            return _norm.TrimNormalizer(maname, **kwargs)
         if ma_class == 'id-apu':
-            return _norm.APUNormalizer(maname, magnet_conv_sign=+1.0)
+            kwargs['magnet_conv_sign'] = +1.0
+            return _norm.APUNormalizer(maname, **kwargs)
         if magfunc == 'corrector-horizontal':
-            return _norm.MagnetNormalizer(maname, magnet_conv_sign=+1.0)
+            kwargs['magnet_conv_sign'] = +1.0
+            return _norm.MagnetNormalizer(maname, **kwargs)
         if 'TB' in maname and 'QD' in maname:
-            return _norm.MagnetNormalizer(maname, magnet_conv_sign=+1.0,)
-        return _norm.MagnetNormalizer(maname, magnet_conv_sign=-1.0)
+            kwargs['magnet_conv_sign'] = +1.0
+            return _norm.MagnetNormalizer(maname, **kwargs)
+        kwargs['magnet_conv_sign'] = -1.0
+        return _norm.MagnetNormalizer(maname, **kwargs)
