@@ -1,5 +1,6 @@
 """Module to deal with orbit acquisition."""
 import logging as _log
+
 import numpy as _np
 
 from ..epics import PV as _PV
@@ -15,23 +16,22 @@ TIMEOUT = 0.05
 
 class BPM(_BaseTimingConfig):
     """."""
+    MAX_UPT_CNT = 20  # equivalent of 10s of orbit update after Acq. PV update
 
     def __init__(self, name, callback=None):
         """."""
         super().__init__(name[:2], callback)
-        self.needs_update = True
+        self.needs_update_cnt = self.MAX_UPT_CNT
 
         self._name = name
         self._orb_conv_unit = self._csorb.ORBIT_CONVERSION_UNIT
         pvpref = LL_PREF + ('-' if LL_PREF else '') + self._name + ':'
-        opt = {'connection_timeout': TIMEOUT}
+        opt = {'connection_timeout': TIMEOUT, 'auto_monitor': False}
         self._poskx = _PV(pvpref + 'PosKx-RB', **opt)
         self._posky = _PV(pvpref + 'PosKy-RB', **opt)
         self._ksum = _PV(pvpref + 'PosKsum-RB', **opt)
         self._polyx = _PV(pvpref + 'GEN_PolyXArrayCoeff-RB', **opt)
         self._polyy = _PV(pvpref + 'GEN_PolyYArrayCoeff-RB', **opt)
-        opt['callback'] = self._set_needs_update
-        opt['auto_monitor'] = True
         self._arraya = _PV(pvpref + 'GEN_AArrayData', **opt)
         self._arrayb = _PV(pvpref + 'GEN_BArrayData', **opt)
         self._arrayc = _PV(pvpref + 'GEN_CArrayData', **opt)
@@ -39,7 +39,6 @@ class BPM(_BaseTimingConfig):
         self._arrayx = _PV(pvpref + 'GEN_XArrayData', **opt)
         self._arrayy = _PV(pvpref + 'GEN_YArrayData', **opt)
         self._arrays = _PV(pvpref + 'GEN_SUMArrayData', **opt)
-        opt.pop('callback')
         opt.pop('auto_monitor')
         self._offsetx = _PV(pvpref + 'PosXOffset-RB', **opt)
         self._offsety = _PV(pvpref + 'PosYOffset-RB', **opt)
@@ -61,17 +60,17 @@ class BPM(_BaseTimingConfig):
             # 'ACQTriggerType': _csbpm.AcqTrigTyp.External,
             'ACQTrigger': _csbpm.AcqTrigTyp.External,
             'ACQTriggerRep': _csbpm.AcqRepeat.Repetitive,
-            # 'ACQTriggerDataChan': _csbpm.AcqChan.Monit1,
+            # 'ACQTriggerDataChan': _csbpm.AcqChan.FAcq,
             'ACQDataTrigChan': _csbpm.AcqChan.ADC,
-            'TbtTagEn': _csbpm.EnbldDsbld.disabled,  # Enable TbT sync Timing
-            'SwTagEn': _csbpm.EnbldDsbld.disabled,  # Enable FOFB sync Timing
-            'Monit1TagEn': _csbpm.EnbldDsbld.disabled,
-            'MonitTagEn': _csbpm.EnbldDsbld.disabled,
-            'TbtDataMaskEn': _csbpm.EnbldDsbld.disabled,  # Enable use of mask
-            'TbtDataMaskSamplesBeg': 0,
-            'TbtDataMaskSamplesEnd': 0,
-            'XYPosCal': _csbpm.EnbldDsbld.enabled,
-            'SUMPosCal': _csbpm.EnbldDsbld.enabled}
+            'TbTTagEn': _csbpm.DsblEnbl.disabled,  # Enable TbT sync Timing
+            'SwTagEn': _csbpm.DsblEnbl.disabled,  # Enable FOFB sync Timing
+            'FAcqTagEn': _csbpm.DsblEnbl.disabled,
+            'MonitTagEn': _csbpm.DsblEnbl.disabled,
+            'TbTDataMaskEn': _csbpm.DsblEnbl.disabled,  # Enable use of mask
+            'TbTDataMaskSamplesBeg': 0,
+            'TbTDataMaskSamplesEnd': 0,
+            'XYPosCal': _csbpm.DsblEnbl.enabled,
+            'SUMPosCal': _csbpm.DsblEnbl.enabled}
         pvs = {
             'asyn.ENBL': 'asyn.ENBL',
             'SwMode': 'SwMode-Sel',
@@ -92,13 +91,13 @@ class BPM(_BaseTimingConfig):
             'ACQTriggerRep': 'ACQTriggerRep-Sel',
             # 'ACQTriggerDataChan': 'ACQTriggerDataChan-Sel',
             'ACQDataTrigChan': 'ACQDataTrigChan-Sel',
-            'TbtTagEn': 'TbtTagEn-Sel',  # Enable TbT sync with timing
+            'TbTTagEn': 'TbTTagEn-Sel',  # Enable TbT sync with timing
             'SwTagEn': 'SwTagEn-Sel',  # Enable FOFB sync with timing
-            'Monit1TagEn': 'Monit1TagEn-Sel',  # Enable Monit1 sync with timing
+            'FAcqTagEn': 'FAcqTagEn-Sel',  # Enable FAcq sync with timing
             'MonitTagEn': 'MonitTagEn-Sel',  # Enable Monit sync with timing
-            'TbtDataMaskEn': 'TbtDataMaskEn-Sel',  # Enable use of mask
-            'TbtDataMaskSamplesBeg': 'TbtDataMaskSamplesBeg-SP',
-            'TbtDataMaskSamplesEnd': 'TbtDataMaskSamplesEnd-SP',
+            'TbTDataMaskEn': 'TbTDataMaskEn-Sel',  # Enable use of mask
+            'TbTDataMaskSamplesBeg': 'TbTDataMaskSamplesBeg-SP',
+            'TbTDataMaskSamplesEnd': 'TbTDataMaskSamplesEnd-SP',
             'XYPosCal': 'XYPosCal-Sel',
             'SUMPosCal': 'SUMPosCal-Sel'}
 
@@ -109,10 +108,10 @@ class BPM(_BaseTimingConfig):
             'asyn.CNCT': 'asyn.CNCT',
             'INFOClkFreq': 'INFOClkFreq-RB',
             'INFOHarmonicNumber': 'INFOHarmonicNumber-RB',
-            'INFOTBTRate': 'INFOTBTRate-RB',
+            'INFOTbTRate': 'INFOTbTRate-RB',
             'INFOFOFBRate': 'INFOFOFBRate-RB',
             'INFOMONITRate': 'INFOMONITRate-RB',
-            'INFOMONIT1Rate': 'INFOMONIT1Rate-RB',
+            'INFOFAcqRate': 'INFOFAcqRate-RB',
             'SwMode': 'SwMode-Sts',
             'ACQBPMMode': 'ACQBPMMode-Sts',
             'ACQChannel': 'ACQChannel-Sts',
@@ -133,17 +132,20 @@ class BPM(_BaseTimingConfig):
             'ACQTriggerRep': 'ACQTriggerRep-Sts',
             # 'ACQTriggerDataChan': 'ACQTriggerDataChan-Sts',
             'ACQDataTrigChan': 'ACQDataTrigChan-Sts',
-            'TbtTagEn': 'TbtTagEn-Sts',
+            'TbTTagEn': 'TbTTagEn-Sts',
             'SwTagEn': 'SwTagEn-Sts',
-            'Monit1TagEn': 'Monit1TagEn-Sts',
+            'FAcqTagEn': 'FAcqTagEn-Sts',
             'MonitTagEn': 'MonitTagEn-Sts',
-            'TbtDataMaskEn': 'TbtDataMaskEn-Sts',
-            'TbtDataMaskSamplesBeg': 'TbtDataMaskSamplesBeg-RB',
-            'TbtDataMaskSamplesEnd': 'TbtDataMaskSamplesEnd-RB',
+            'TbTDataMaskEn': 'TbTDataMaskEn-Sts',
+            'TbTDataMaskSamplesBeg': 'TbTDataMaskSamplesBeg-RB',
+            'TbTDataMaskSamplesEnd': 'TbTDataMaskSamplesEnd-RB',
             'XYPosCal': 'XYPosCal-Sts',
             'SUMPosCal': 'SUMPosCal-Sts'}
         self._config_pvs_rb = {
             k: _PV(pvpref + v, **opt) for k, v in pvs.items()}
+        self._config_pvs_rb['ACQStatus'].auto_monitor = True
+        self._config_pvs_rb['ACQStatus'].add_callback(
+            self._reset_needs_update_cnt)
 
     @property
     def name(self):
@@ -235,7 +237,7 @@ class BPM(_BaseTimingConfig):
     def tbtrate(self):
         """."""
         defv = 362 if self._csorb.acc == 'BO' else 382
-        pvobj = self._config_pvs_rb['INFOTBTRate']
+        pvobj = self._config_pvs_rb['INFOTbTRate']
         val = pvobj.value if pvobj.connected else defv
         return val if val else defv
 
@@ -271,17 +273,17 @@ class BPM(_BaseTimingConfig):
         return self.monitrate / self.adcfreq
 
     @property
-    def monit1rate(self):
+    def facqrate(self):
         """."""
         defv = (362 if self._csorb.acc == 'BO' else 382) * 603
-        pvobj = self._config_pvs_rb['INFOMONIT1Rate']
+        pvobj = self._config_pvs_rb['INFOFAcqRate']
         val = pvobj.value if pvobj.connected else defv
         return val if val else defv
 
     @property
-    def monit1period(self):
+    def facqperiod(self):
         """."""
-        return self.monit1rate / self.adcfreq
+        return self.facqrate / self.adcfreq
 
     @property
     def poskx(self):
@@ -491,14 +493,14 @@ class BPM(_BaseTimingConfig):
     @property
     def tbt_sync_enbl(self):
         """."""
-        pvobj = self._config_pvs_rb['TbtTagEn']
+        pvobj = self._config_pvs_rb['TbTTagEn']
         return pvobj.value if pvobj.connected else None
 
     @tbt_sync_enbl.setter
     def tbt_sync_enbl(self, val):
         """."""
-        pvobj = self._config_pvs_sp['TbtTagEn']
-        self._config_ok_vals['TbtTagEn'] = val
+        pvobj = self._config_pvs_sp['TbTTagEn']
+        self._config_ok_vals['TbTTagEn'] = val
         if self.put_enable and pvobj.connected:
             pvobj.put(val, wait=False)
 
@@ -517,15 +519,15 @@ class BPM(_BaseTimingConfig):
             pvobj.put(val, wait=False)
 
     @property
-    def monit1_sync_enbl(self):
+    def facq_sync_enbl(self):
         """."""
-        pvobj = self._config_pvs_rb['Monit1TagEn']
+        pvobj = self._config_pvs_rb['FAcqTagEn']
         return pvobj.value if pvobj.connected else None
 
-    @monit1_sync_enbl.setter
-    def monit1_sync_enbl(self, val):
+    @facq_sync_enbl.setter
+    def facq_sync_enbl(self, val):
         """."""
-        pvobj = self._config_pvs_sp['Monit1TagEn']
+        pvobj = self._config_pvs_sp['FAcqTagEn']
         if self.put_enable and pvobj.connected:
             pvobj.put(val, wait=False)
 
@@ -545,42 +547,42 @@ class BPM(_BaseTimingConfig):
     @property
     def tbt_mask_enbl(self):
         """."""
-        pvobj = self._config_pvs_rb['TbtDataMaskEn']
+        pvobj = self._config_pvs_rb['TbTDataMaskEn']
         return pvobj.value if pvobj.connected else None
 
     @tbt_mask_enbl.setter
     def tbt_mask_enbl(self, val):
         """."""
-        pvobj = self._config_pvs_sp['TbtDataMaskEn']
-        self._config_ok_vals['TbtDataMaskEn'] = val
+        pvobj = self._config_pvs_sp['TbTDataMaskEn']
+        self._config_ok_vals['TbTDataMaskEn'] = val
         if self.put_enable and pvobj.connected:
             pvobj.put(val, wait=False)
 
     @property
     def tbt_mask_begin(self):
         """."""
-        pvobj = self._config_pvs_rb['TbtDataMaskSamplesBeg']
+        pvobj = self._config_pvs_rb['TbTDataMaskSamplesBeg']
         return pvobj.value if pvobj.connected else None
 
     @tbt_mask_begin.setter
     def tbt_mask_begin(self, val):
         """."""
-        pvobj = self._config_pvs_sp['TbtDataMaskSamplesBeg']
-        self._config_ok_vals['TbtDataMaskSamplesBeg'] = val
+        pvobj = self._config_pvs_sp['TbTDataMaskSamplesBeg']
+        self._config_ok_vals['TbTDataMaskSamplesBeg'] = val
         if self.put_enable and pvobj.connected:
             pvobj.put(val, wait=False)
 
     @property
     def tbt_mask_end(self):
         """."""
-        pvobj = self._config_pvs_rb['TbtDataMaskSamplesEnd']
+        pvobj = self._config_pvs_rb['TbTDataMaskSamplesEnd']
         return pvobj.value if pvobj.connected else None
 
     @tbt_mask_end.setter
     def tbt_mask_end(self, val):
         """."""
-        pvobj = self._config_pvs_sp['TbtDataMaskSamplesEnd']
-        self._config_ok_vals['TbtDataMaskSamplesEnd'] = val
+        pvobj = self._config_pvs_sp['TbTDataMaskSamplesEnd']
+        self._config_ok_vals['TbTDataMaskSamplesEnd'] = val
         if self.put_enable and pvobj.connected:
             pvobj.put(val, wait=False)
 
@@ -593,7 +595,7 @@ class BPM(_BaseTimingConfig):
     @polycal.setter
     def polycal(self, val):
         """."""
-        val = _csbpm.EnbldDsbld.enabled if val else _csbpm.EnbldDsbld.disabled
+        val = _csbpm.DsblEnbl.enabled if val else _csbpm.DsblEnbl.disabled
         pv1 = self._config_pvs_sp['XYPosCal']
         pv2 = self._config_pvs_sp['SUMPosCal']
         self._config_ok_vals['XYPosCal'] = val
@@ -703,7 +705,7 @@ class BPM(_BaseTimingConfig):
         diff2 = (vals['D'][zero2] - vals['B'][zero2]) / sum2[zero2]
         x_uncal = (diff1 + diff2) / 2
         y_uncal = (diff1 - diff2) / 2
-        if self._config_ok_vals['XYPosCal'] == _csbpm.EnbldDsbld.disabled:
+        if self._config_ok_vals['XYPosCal'] == _csbpm.DsblEnbl.disabled:
             x_cal[:rnts][zero1] = x_uncal * self.poskx
             y_cal[:rnts][zero2] = y_uncal * self.posky
         else:
@@ -742,9 +744,9 @@ class BPM(_BaseTimingConfig):
             th7*(pol[12] + ot2*pol[13]) +
             th9*pol[14])
 
-    def _set_needs_update(self, *args, **kwargs):
+    def _reset_needs_update_cnt(self, *args, **kwargs):
         _ = args, kwargs
-        self.needs_update = True
+        self.needs_update_cnt = self.MAX_UPT_CNT
 
 
 class TimingConfig(_BaseTimingConfig):
